# coding: utf-8

# flake8: noqa
"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

if __import__("typing").TYPE_CHECKING:
    # import models into model package
    from biotmed_settings_sdk.models.add_locale_request import AddLocaleRequest
    from biotmed_settings_sdk.models.attribute_analytics_db_configuration import AttributeAnalyticsDbConfiguration
    from biotmed_settings_sdk.models.attribute_identifier import AttributeIdentifier
    from biotmed_settings_sdk.models.backup_request import BackupRequest
    from biotmed_settings_sdk.models.backup_response import BackupResponse
    from biotmed_settings_sdk.models.base_locale import BaseLocale
    from biotmed_settings_sdk.models.base_selectable_value import BaseSelectableValue
    from biotmed_settings_sdk.models.basic_attribute_data import BasicAttributeData
    from biotmed_settings_sdk.models.basic_template_data import BasicTemplateData
    from biotmed_settings_sdk.models.built_in_attribute import BuiltInAttribute
    from biotmed_settings_sdk.models.category import Category
    from biotmed_settings_sdk.models.code_snippet_response import CodeSnippetResponse
    from biotmed_settings_sdk.models.create_built_in_attribute import CreateBuiltInAttribute
    from biotmed_settings_sdk.models.create_code_snippet_request import CreateCodeSnippetRequest
    from biotmed_settings_sdk.models.create_custom_attribute import CreateCustomAttribute
    from biotmed_settings_sdk.models.create_plugin_request import CreatePluginRequest
    from biotmed_settings_sdk.models.create_template_attribute import CreateTemplateAttribute
    from biotmed_settings_sdk.models.create_template_request import CreateTemplateRequest
    from biotmed_settings_sdk.models.credentials import Credentials
    from biotmed_settings_sdk.models.custom_attribute import CustomAttribute
    from biotmed_settings_sdk.models.docker_repository_temp_credentials_response import DockerRepositoryTempCredentialsResponse
    from biotmed_settings_sdk.models.entity_notifiable_action import EntityNotifiableAction
    from biotmed_settings_sdk.models.entity_type import EntityType
    from biotmed_settings_sdk.models.entity_type_built_in_action import EntityTypeBuiltInAction
    from biotmed_settings_sdk.models.entity_type_built_in_attribute import EntityTypeBuiltInAttribute
    from biotmed_settings_sdk.models.entity_type_template_attribute import EntityTypeTemplateAttribute
    from biotmed_settings_sdk.models.error_response import ErrorResponse
    from biotmed_settings_sdk.models.export_execution_response import ExportExecutionResponse
    from biotmed_settings_sdk.models.exports_metadata_response import ExportsMetadataResponse
    from biotmed_settings_sdk.models.file_configuration_metadata_response import FileConfigurationMetadataResponse
    from biotmed_settings_sdk.models.filter_v2 import FilterV2
    from biotmed_settings_sdk.models.get_category_response import GetCategoryResponse
    from biotmed_settings_sdk.models.get_entity_types_response import GetEntityTypesResponse
    from biotmed_settings_sdk.models.get_notifiable_actions import GetNotifiableActions
    from biotmed_settings_sdk.models.get_template_response import GetTemplateResponse
    from biotmed_settings_sdk.models.import_execution_response import ImportExecutionResponse
    from biotmed_settings_sdk.models.interception_configuration_response import InterceptionConfigurationResponse
    from biotmed_settings_sdk.models.interception_subscription_dto import InterceptionSubscriptionDto
    from biotmed_settings_sdk.models.invalid_translation import InvalidTranslation
    from biotmed_settings_sdk.models.json_nullable_list_cors_allowed_http_method_enum import JsonNullableListCorsAllowedHttpMethodEnum
    from biotmed_settings_sdk.models.json_nullable_list_interception_subscription_dto import JsonNullableListInterceptionSubscriptionDto
    from biotmed_settings_sdk.models.json_nullable_list_notification_subscription_dto import JsonNullableListNotificationSubscriptionDto
    from biotmed_settings_sdk.models.json_nullable_list_string import JsonNullableListString
    from biotmed_settings_sdk.models.json_nullable_set_base_locale import JsonNullableSetBaseLocale
    from biotmed_settings_sdk.models.link_configuration import LinkConfiguration
    from biotmed_settings_sdk.models.locale_translations_coverage import LocaleTranslationsCoverage
    from biotmed_settings_sdk.models.locale_translations_overview import LocaleTranslationsOverview
    from biotmed_settings_sdk.models.locales_response import LocalesResponse
    from biotmed_settings_sdk.models.metadata import Metadata
    from biotmed_settings_sdk.models.notification_subscription_dto import NotificationSubscriptionDto
    from biotmed_settings_sdk.models.numeric_meta_data import NumericMetaData
    from biotmed_settings_sdk.models.order import Order
    from biotmed_settings_sdk.models.organization_selection import OrganizationSelection
    from biotmed_settings_sdk.models.organization_selection_configuration import OrganizationSelectionConfiguration
    from biotmed_settings_sdk.models.page_metadata import PageMetadata
    from biotmed_settings_sdk.models.parent_template_response import ParentTemplateResponse
    from biotmed_settings_sdk.models.partial_plugin_cors_config import PartialPluginCorsConfig
    from biotmed_settings_sdk.models.partial_update_plugin_request import PartialUpdatePluginRequest
    from biotmed_settings_sdk.models.partial_update_subscription_dto import PartialUpdateSubscriptionDto
    from biotmed_settings_sdk.models.plugin_cors_config import PluginCorsConfig
    from biotmed_settings_sdk.models.plugin_response import PluginResponse
    from biotmed_settings_sdk.models.primary_administrator import PrimaryAdministrator
    from biotmed_settings_sdk.models.reference_configuration import ReferenceConfiguration
    from biotmed_settings_sdk.models.reset_system_request import ResetSystemRequest
    from biotmed_settings_sdk.models.restore_response import RestoreResponse
    from biotmed_settings_sdk.models.search_request_v2 import SearchRequestV2
    from biotmed_settings_sdk.models.search_response_backup_response import SearchResponseBackupResponse
    from biotmed_settings_sdk.models.search_response_code_snippet_response import SearchResponseCodeSnippetResponse
    from biotmed_settings_sdk.models.search_response_entity_type import SearchResponseEntityType
    from biotmed_settings_sdk.models.search_response_get_template_response import SearchResponseGetTemplateResponse
    from biotmed_settings_sdk.models.search_response_interception_configuration_response import SearchResponseInterceptionConfigurationResponse
    from biotmed_settings_sdk.models.search_response_locale_translations_overview import SearchResponseLocaleTranslationsOverview
    from biotmed_settings_sdk.models.search_response_plugin_response import SearchResponsePluginResponse
    from biotmed_settings_sdk.models.search_response_restore_response import SearchResponseRestoreResponse
    from biotmed_settings_sdk.models.search_response_template_minimized_response import SearchResponseTemplateMinimizedResponse
    from biotmed_settings_sdk.models.selectable_value import SelectableValue
    from biotmed_settings_sdk.models.selected_organization import SelectedOrganization
    from biotmed_settings_sdk.models.start_export_configuration_request import StartExportConfigurationRequest
    from biotmed_settings_sdk.models.start_import_configuration_request import StartImportConfigurationRequest
    from biotmed_settings_sdk.models.subscription_dto import SubscriptionDto
    from biotmed_settings_sdk.models.system_properties_response import SystemPropertiesResponse
    from biotmed_settings_sdk.models.template_analytics_db_configuration import TemplateAnalyticsDbConfiguration
    from biotmed_settings_sdk.models.template_attribute import TemplateAttribute
    from biotmed_settings_sdk.models.template_minimized_response import TemplateMinimizedResponse
    from biotmed_settings_sdk.models.template_overview_response import TemplateOverviewResponse
    from biotmed_settings_sdk.models.template_statistics import TemplateStatistics
    from biotmed_settings_sdk.models.update_built_in_attribute import UpdateBuiltInAttribute
    from biotmed_settings_sdk.models.update_custom_attribute import UpdateCustomAttribute
    from biotmed_settings_sdk.models.update_locale_translations_response import UpdateLocaleTranslationsResponse
    from biotmed_settings_sdk.models.update_locales_request import UpdateLocalesRequest
    from biotmed_settings_sdk.models.update_template_attribute import UpdateTemplateAttribute
    from biotmed_settings_sdk.models.update_template_request import UpdateTemplateRequest
    from biotmed_settings_sdk.models.validate_locale_translations_response import ValidateLocaleTranslationsResponse
    from biotmed_settings_sdk.models.validation_definition_metadata_object import ValidationDefinitionMetadataObject
    from biotmed_settings_sdk.models.validation_definition_object import ValidationDefinitionObject
    from biotmed_settings_sdk.models.version_response import VersionResponse
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            """# import models into model package
from biotmed_settings_sdk.models.add_locale_request import AddLocaleRequest
from biotmed_settings_sdk.models.attribute_analytics_db_configuration import AttributeAnalyticsDbConfiguration
from biotmed_settings_sdk.models.attribute_identifier import AttributeIdentifier
from biotmed_settings_sdk.models.backup_request import BackupRequest
from biotmed_settings_sdk.models.backup_response import BackupResponse
from biotmed_settings_sdk.models.base_locale import BaseLocale
from biotmed_settings_sdk.models.base_selectable_value import BaseSelectableValue
from biotmed_settings_sdk.models.basic_attribute_data import BasicAttributeData
from biotmed_settings_sdk.models.basic_template_data import BasicTemplateData
from biotmed_settings_sdk.models.built_in_attribute import BuiltInAttribute
from biotmed_settings_sdk.models.category import Category
from biotmed_settings_sdk.models.code_snippet_response import CodeSnippetResponse
from biotmed_settings_sdk.models.create_built_in_attribute import CreateBuiltInAttribute
from biotmed_settings_sdk.models.create_code_snippet_request import CreateCodeSnippetRequest
from biotmed_settings_sdk.models.create_custom_attribute import CreateCustomAttribute
from biotmed_settings_sdk.models.create_plugin_request import CreatePluginRequest
from biotmed_settings_sdk.models.create_template_attribute import CreateTemplateAttribute
from biotmed_settings_sdk.models.create_template_request import CreateTemplateRequest
from biotmed_settings_sdk.models.credentials import Credentials
from biotmed_settings_sdk.models.custom_attribute import CustomAttribute
from biotmed_settings_sdk.models.docker_repository_temp_credentials_response import DockerRepositoryTempCredentialsResponse
from biotmed_settings_sdk.models.entity_notifiable_action import EntityNotifiableAction
from biotmed_settings_sdk.models.entity_type import EntityType
from biotmed_settings_sdk.models.entity_type_built_in_action import EntityTypeBuiltInAction
from biotmed_settings_sdk.models.entity_type_built_in_attribute import EntityTypeBuiltInAttribute
from biotmed_settings_sdk.models.entity_type_template_attribute import EntityTypeTemplateAttribute
from biotmed_settings_sdk.models.error_response import ErrorResponse
from biotmed_settings_sdk.models.export_execution_response import ExportExecutionResponse
from biotmed_settings_sdk.models.exports_metadata_response import ExportsMetadataResponse
from biotmed_settings_sdk.models.file_configuration_metadata_response import FileConfigurationMetadataResponse
from biotmed_settings_sdk.models.filter_v2 import FilterV2
from biotmed_settings_sdk.models.get_category_response import GetCategoryResponse
from biotmed_settings_sdk.models.get_entity_types_response import GetEntityTypesResponse
from biotmed_settings_sdk.models.get_notifiable_actions import GetNotifiableActions
from biotmed_settings_sdk.models.get_template_response import GetTemplateResponse
from biotmed_settings_sdk.models.import_execution_response import ImportExecutionResponse
from biotmed_settings_sdk.models.interception_configuration_response import InterceptionConfigurationResponse
from biotmed_settings_sdk.models.interception_subscription_dto import InterceptionSubscriptionDto
from biotmed_settings_sdk.models.invalid_translation import InvalidTranslation
from biotmed_settings_sdk.models.json_nullable_list_cors_allowed_http_method_enum import JsonNullableListCorsAllowedHttpMethodEnum
from biotmed_settings_sdk.models.json_nullable_list_interception_subscription_dto import JsonNullableListInterceptionSubscriptionDto
from biotmed_settings_sdk.models.json_nullable_list_notification_subscription_dto import JsonNullableListNotificationSubscriptionDto
from biotmed_settings_sdk.models.json_nullable_list_string import JsonNullableListString
from biotmed_settings_sdk.models.json_nullable_set_base_locale import JsonNullableSetBaseLocale
from biotmed_settings_sdk.models.link_configuration import LinkConfiguration
from biotmed_settings_sdk.models.locale_translations_coverage import LocaleTranslationsCoverage
from biotmed_settings_sdk.models.locale_translations_overview import LocaleTranslationsOverview
from biotmed_settings_sdk.models.locales_response import LocalesResponse
from biotmed_settings_sdk.models.metadata import Metadata
from biotmed_settings_sdk.models.notification_subscription_dto import NotificationSubscriptionDto
from biotmed_settings_sdk.models.numeric_meta_data import NumericMetaData
from biotmed_settings_sdk.models.order import Order
from biotmed_settings_sdk.models.organization_selection import OrganizationSelection
from biotmed_settings_sdk.models.organization_selection_configuration import OrganizationSelectionConfiguration
from biotmed_settings_sdk.models.page_metadata import PageMetadata
from biotmed_settings_sdk.models.parent_template_response import ParentTemplateResponse
from biotmed_settings_sdk.models.partial_plugin_cors_config import PartialPluginCorsConfig
from biotmed_settings_sdk.models.partial_update_plugin_request import PartialUpdatePluginRequest
from biotmed_settings_sdk.models.partial_update_subscription_dto import PartialUpdateSubscriptionDto
from biotmed_settings_sdk.models.plugin_cors_config import PluginCorsConfig
from biotmed_settings_sdk.models.plugin_response import PluginResponse
from biotmed_settings_sdk.models.primary_administrator import PrimaryAdministrator
from biotmed_settings_sdk.models.reference_configuration import ReferenceConfiguration
from biotmed_settings_sdk.models.reset_system_request import ResetSystemRequest
from biotmed_settings_sdk.models.restore_response import RestoreResponse
from biotmed_settings_sdk.models.search_request_v2 import SearchRequestV2
from biotmed_settings_sdk.models.search_response_backup_response import SearchResponseBackupResponse
from biotmed_settings_sdk.models.search_response_code_snippet_response import SearchResponseCodeSnippetResponse
from biotmed_settings_sdk.models.search_response_entity_type import SearchResponseEntityType
from biotmed_settings_sdk.models.search_response_get_template_response import SearchResponseGetTemplateResponse
from biotmed_settings_sdk.models.search_response_interception_configuration_response import SearchResponseInterceptionConfigurationResponse
from biotmed_settings_sdk.models.search_response_locale_translations_overview import SearchResponseLocaleTranslationsOverview
from biotmed_settings_sdk.models.search_response_plugin_response import SearchResponsePluginResponse
from biotmed_settings_sdk.models.search_response_restore_response import SearchResponseRestoreResponse
from biotmed_settings_sdk.models.search_response_template_minimized_response import SearchResponseTemplateMinimizedResponse
from biotmed_settings_sdk.models.selectable_value import SelectableValue
from biotmed_settings_sdk.models.selected_organization import SelectedOrganization
from biotmed_settings_sdk.models.start_export_configuration_request import StartExportConfigurationRequest
from biotmed_settings_sdk.models.start_import_configuration_request import StartImportConfigurationRequest
from biotmed_settings_sdk.models.subscription_dto import SubscriptionDto
from biotmed_settings_sdk.models.system_properties_response import SystemPropertiesResponse
from biotmed_settings_sdk.models.template_analytics_db_configuration import TemplateAnalyticsDbConfiguration
from biotmed_settings_sdk.models.template_attribute import TemplateAttribute
from biotmed_settings_sdk.models.template_minimized_response import TemplateMinimizedResponse
from biotmed_settings_sdk.models.template_overview_response import TemplateOverviewResponse
from biotmed_settings_sdk.models.template_statistics import TemplateStatistics
from biotmed_settings_sdk.models.update_built_in_attribute import UpdateBuiltInAttribute
from biotmed_settings_sdk.models.update_custom_attribute import UpdateCustomAttribute
from biotmed_settings_sdk.models.update_locale_translations_response import UpdateLocaleTranslationsResponse
from biotmed_settings_sdk.models.update_locales_request import UpdateLocalesRequest
from biotmed_settings_sdk.models.update_template_attribute import UpdateTemplateAttribute
from biotmed_settings_sdk.models.update_template_request import UpdateTemplateRequest
from biotmed_settings_sdk.models.validate_locale_translations_response import ValidateLocaleTranslationsResponse
from biotmed_settings_sdk.models.validation_definition_metadata_object import ValidationDefinitionMetadataObject
from biotmed_settings_sdk.models.validation_definition_object import ValidationDefinitionObject
from biotmed_settings_sdk.models.version_response import VersionResponse

""",
            name=__name__,
            doc=__doc__,
        )
    )
