# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.template_minimized_response import TemplateMinimizedResponse

class TestTemplateMinimizedResponse(unittest.TestCase):
    """TemplateMinimizedResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TemplateMinimizedResponse:
        """Test TemplateMinimizedResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TemplateMinimizedResponse`
        """
        model = TemplateMinimizedResponse()
        if include_optional:
            return TemplateMinimizedResponse(
                display_name = '0',
                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua0',
                description = '0',
                owner_organization_id = '',
                analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                    name = '', ),
                id = '',
                entity_type_name = '',
                removable = True,
                creation_time = '2007-12-20T10:15:30Z',
                last_modified_time = '2007-12-20T10:15:30Z',
                parent_template = biotmed_settings_sdk.models.parent_template_response.ParentTemplateResponse(
                    id = '', 
                    display_name = '', 
                    name = '', ),
                parent_template_id = ''
            )
        else:
            return TemplateMinimizedResponse(
                display_name = '0',
                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua0',
                creation_time = '2007-12-20T10:15:30Z',
                last_modified_time = '2007-12-20T10:15:30Z',
        )
        """

    def testTemplateMinimizedResponse(self):
        """Test TemplateMinimizedResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
