# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.plugin_response import PluginResponse

class TestPluginResponse(unittest.TestCase):
    """PluginResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PluginResponse:
        """Test PluginResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PluginResponse`
        """
        model = PluginResponse()
        if include_optional:
            return PluginResponse(
                name = 'My-Plugin_3',
                display_name = 'My Plugin 3',
                version = 1,
                runtime = 'python3.13',
                handler = 'index.handler',
                timeout = 60,
                memory_size = 60,
                environment_variables = {
                    'key' : ''
                    },
                subscriptions = biotmed_settings_sdk.models.subscription_dto.SubscriptionDto(
                    interception_order = 56, 
                    interceptions = [
                        biotmed_settings_sdk.models.interception_subscription_dto.InterceptionSubscriptionDto(
                            type = 'PRE_REQUEST', 
                            api_id = '', 
                            entity_type_name = 'device', 
                            order = 56, )
                        ], 
                    notifications = [
                        biotmed_settings_sdk.models.notification_subscription_dto.NotificationSubscriptionDto(
                            entity_type_name = 'device', 
                            action_name = '_create', )
                        ], ),
                enabled_state = 'ENABLED',
                cron_schedule = '45',
                deployment_package_type = 'ZIP',
                analytics_db_access = True,
                cors = biotmed_settings_sdk.models.plugin_cors_config.PluginCorsConfig(
                    allow_origins = [*], 
                    allow_methods = [GET, POST], 
                    allow_headers = [authorization, content-type], 
                    expose_headers = [], ),
                ephemeral_storage = 512,
                endpoint_url = '',
                link_to_console = '',
                last_modified_time = '2007-12-20T10:15:30Z',
                creation_time = '2007-12-20T10:15:30Z'
            )
        else:
            return PluginResponse(
                name = 'My-Plugin_3',
                display_name = 'My Plugin 3',
                version = 1,
                timeout = 60,
                memory_size = 60,
                environment_variables = {
                    'key' : ''
                    },
                enabled_state = 'ENABLED',
                deployment_package_type = 'ZIP',
                analytics_db_access = True,
                endpoint_url = '',
                link_to_console = '',
                last_modified_time = '2007-12-20T10:15:30Z',
                creation_time = '2007-12-20T10:15:30Z',
        )
        """

    def testPluginResponse(self):
        """Test PluginResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
