# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.filter_v2 import FilterV2

class TestFilterV2(unittest.TestCase):
    """FilterV2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FilterV2:
        """Test FilterV2
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FilterV2`
        """
        model = FilterV2()
        if include_optional:
            return FilterV2(
                var_in = [
                    ''
                    ],
                eq = None,
                lt = 20,
                lte = 25,
                gt = 25,
                gte = 25,
                like = 'John',
                var_from = '2007-12-20',
                to = '2007-12-20',
                is_null = True,
                is_not_null = True,
                var_not = None,
                not_in = [
                    ''
                    ],
                filter = None
            )
        else:
            return FilterV2(
        )
        """

    def testFilterV2(self):
        """Test FilterV2"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
