# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.api.locale_api_api import LocaleAPIApi


class TestLocaleAPIApi(unittest.TestCase):
    """LocaleAPIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LocaleAPIApi()

    def tearDown(self) -> None:
        pass

    def test_add_locale(self) -> None:
        """Test case for add_locale

        Add locale to the available locales
        """
        pass

    def test_delete_locale(self) -> None:
        """Test case for delete_locale

        Remove a locale from the available locales
        """
        pass

    def test_get_locales(self) -> None:
        """Test case for get_locales

        Get available locales, the default locale and the system locale
        """
        pass

    def test_update_locales(self) -> None:
        """Test case for update_locales

        Update available locales and/or the system default locale.
        """
        pass


if __name__ == '__main__':
    unittest.main()
