# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.api.interception_configuration_api_api import InterceptionConfigurationAPIApi


class TestInterceptionConfigurationAPIApi(unittest.TestCase):
    """InterceptionConfigurationAPIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = InterceptionConfigurationAPIApi()

    def tearDown(self) -> None:
        pass

    def test_search3(self) -> None:
        """Test case for search3

        Search Interception Configurations entities by filter
        """
        pass


if __name__ == '__main__':
    unittest.main()
