# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.entity_type_built_in_attribute import EntityTypeBuiltInAttribute

class TestEntityTypeBuiltInAttribute(unittest.TestCase):
    """EntityTypeBuiltInAttribute unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EntityTypeBuiltInAttribute:
        """Test EntityTypeBuiltInAttribute
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EntityTypeBuiltInAttribute`
        """
        model = EntityTypeBuiltInAttribute()
        if include_optional:
            return EntityTypeBuiltInAttribute(
                name = '',
                base_path = '',
                type = 'LABEL',
                display_name = '',
                phi = True,
                validation = biotmed_settings_sdk.models.validation_definition_object.ValidationDefinitionObject(
                    mandatory = True, 
                    default_value = null, 
                    min = -9223372036854775808, 
                    max = -9223372036854775808, 
                    regex = '', ),
                validation_metadata = biotmed_settings_sdk.models.validation_definition_metadata_object.ValidationDefinitionMetadataObject(
                    mandatory_read_only = True, 
                    system_mandatory = True, 
                    phi_read_only = True, ),
                selectable_values = [
                    biotmed_settings_sdk.models.base_selectable_value.BaseSelectableValue(
                        name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua', 
                        display_name = '', )
                    ],
                read_only = True,
                reference_configuration = biotmed_settings_sdk.models.reference_configuration.ReferenceConfiguration(
                    uniquely = True, 
                    referenced_side_attribute_name = '', 
                    referenced_side_attribute_display_name = '', 
                    valid_templates_to_reference = [
                        ''
                        ], 
                    entity_type = '', ),
                numeric_meta_data = biotmed_settings_sdk.models.numeric_meta_data.NumericMetaData(
                    units = '', 
                    upper_range = -2147483648, 
                    lower_range = -2147483648, 
                    sub_type = 'INTEGER', ),
                category = biotmed_settings_sdk.models.category.Category(
                    name = '', 
                    display_name = '', ),
                analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                    name = '', ),
                type_enum = 'LABEL'
            )
        else:
            return EntityTypeBuiltInAttribute(
                name = '',
        )
        """

    def testEntityTypeBuiltInAttribute(self):
        """Test EntityTypeBuiltInAttribute"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
