# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.api.template_api_api import TemplateAPIApi


class TestTemplateAPIApi(unittest.TestCase):
    """TemplateAPIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TemplateAPIApi()

    def tearDown(self) -> None:
        pass

    def test_create_template(self) -> None:
        """Test case for create_template

        Create a new Template
        """
        pass

    def test_delete_template(self) -> None:
        """Test case for delete_template

        Delete Template
        """
        pass

    def test_get_template(self) -> None:
        """Test case for get_template

        Get Template by ID
        """
        pass

    def test_get_template_overview(self) -> None:
        """Test case for get_template_overview

        Get template overview
        """
        pass

    def test_minimal_search(self) -> None:
        """Test case for minimal_search

        Search Template entities by filter
        """
        pass

    def test_search1(self) -> None:
        """Test case for search1

        Search Template entities by filter
        """
        pass

    def test_update_template(self) -> None:
        """Test case for update_template

        Update Template
        """
        pass


if __name__ == '__main__':
    unittest.main()
