# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.api.translation_api_api import TranslationAPIApi


class TestTranslationAPIApi(unittest.TestCase):
    """TranslationAPIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TranslationAPIApi()

    def tearDown(self) -> None:
        pass

    def test_delete_locale_translations(self) -> None:
        """Test case for delete_locale_translations

        Delete all translations for locale
        """
        pass

    def test_download_locale_translation_file(self) -> None:
        """Test case for download_locale_translation_file

        Download locale translation file
        """
        pass

    def test_search_locale_translation_overviews(self) -> None:
        """Test case for search_locale_translation_overviews

        Search Locale translations overview entities by filter
        """
        pass

    def test_update_locale_translations(self) -> None:
        """Test case for update_locale_translations

        Update translations for locale
        """
        pass

    def test_validate_locale_translations(self) -> None:
        """Test case for validate_locale_translations

        Validate translations for locale
        """
        pass


if __name__ == '__main__':
    unittest.main()
