# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.api.export_import_configuration_api_api import ExportImportConfigurationAPIApi


class TestExportImportConfigurationAPIApi(unittest.TestCase):
    """ExportImportConfigurationAPIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ExportImportConfigurationAPIApi()

    def tearDown(self) -> None:
        pass

    def test_get_exports_metadata(self) -> None:
        """Test case for get_exports_metadata

        Get exported files metadata
        """
        pass

    def test_get_last_export_execution(self) -> None:
        """Test case for get_last_export_execution

        Get the last export execution
        """
        pass

    def test_get_last_import_execution(self) -> None:
        """Test case for get_last_import_execution

        Get the last import execution
        """
        pass

    def test_start_export(self) -> None:
        """Test case for start_export

        Start export configuration
        """
        pass

    def test_start_import(self) -> None:
        """Test case for start_import

        Start import configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()
