# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.docker_repository_temp_credentials_response import DockerRepositoryTempCredentialsResponse

class TestDockerRepositoryTempCredentialsResponse(unittest.TestCase):
    """DockerRepositoryTempCredentialsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DockerRepositoryTempCredentialsResponse:
        """Test DockerRepositoryTempCredentialsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DockerRepositoryTempCredentialsResponse`
        """
        model = DockerRepositoryTempCredentialsResponse()
        if include_optional:
            return DockerRepositoryTempCredentialsResponse(
                credentials = biotmed_settings_sdk.models.credentials.Credentials(
                    access_key_id = '', 
                    secret_access_key = '', 
                    session_token = '', 
                    expiration = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                region = '',
                repository_uri = ''
            )
        else:
            return DockerRepositoryTempCredentialsResponse(
        )
        """

    def testDockerRepositoryTempCredentialsResponse(self):
        """Test DockerRepositoryTempCredentialsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
