# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.get_category_response import GetCategoryResponse

class TestGetCategoryResponse(unittest.TestCase):
    """GetCategoryResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetCategoryResponse:
        """Test GetCategoryResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetCategoryResponse`
        """
        model = GetCategoryResponse()
        if include_optional:
            return GetCategoryResponse(
                name = '',
                display_name = '',
                built_in_supported_types = [
                    'LABEL'
                    ],
                custom_supported_types = [
                    'LABEL'
                    ],
                allowed_categories_to_link_to = [
                    ''
                    ],
                support_mandatory_validation = True,
                custom_base_path = ''
            )
        else:
            return GetCategoryResponse(
                name = '',
                display_name = '',
        )
        """

    def testGetCategoryResponse(self):
        """Test GetCategoryResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
