# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.update_locales_request import UpdateLocalesRequest

class TestUpdateLocalesRequest(unittest.TestCase):
    """UpdateLocalesRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateLocalesRequest:
        """Test UpdateLocalesRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateLocalesRequest`
        """
        model = UpdateLocalesRequest()
        if include_optional:
            return UpdateLocalesRequest(
                available_locales = biotmed_settings_sdk.models.json_nullable_list_interception_subscription_dto.JsonNullableListInterceptionSubscriptionDto(
                    present = True, ),
                default_locale_code = 'en-us'
            )
        else:
            return UpdateLocalesRequest(
        )
        """

    def testUpdateLocalesRequest(self):
        """Test UpdateLocalesRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
