# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.locales_response import LocalesResponse

class TestLocalesResponse(unittest.TestCase):
    """LocalesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LocalesResponse:
        """Test LocalesResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LocalesResponse`
        """
        model = LocalesResponse()
        if include_optional:
            return LocalesResponse(
                available_locales = [
                    biotmed_settings_sdk.models.base_locale.BaseLocale(
                        code = 'en-us', 
                        hidden = False, 
                        translation_fallback_types = [
                            'DEFAULT_LOCALE'
                            ], )
                    ],
                default_locale_code = 'en-us',
                system_locale_code = ''
            )
        else:
            return LocalesResponse(
        )
        """

    def testLocalesResponse(self):
        """Test LocalesResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
