# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.backup_response import BackupResponse

class TestBackupResponse(unittest.TestCase):
    """BackupResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BackupResponse:
        """Test BackupResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BackupResponse`
        """
        model = BackupResponse()
        if include_optional:
            return BackupResponse(
                name = 'Backup-01-02-2024',
                backup_version = '2.3.11',
                error_message = 'No internet connection',
                build_number = 12345,
                last_modified_time = '2007-12-20T10:15:30Z',
                creation_time = '2007-12-20T10:15:30Z',
                description = 'Backup after entity creation',
                status = 'SUCCESS'
            )
        else:
            return BackupResponse(
                name = 'Backup-01-02-2024',
                backup_version = '2.3.11',
                build_number = 12345,
                last_modified_time = '2007-12-20T10:15:30Z',
                creation_time = '2007-12-20T10:15:30Z',
                status = 'SUCCESS',
        )
        """

    def testBackupResponse(self):
        """Test BackupResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
