# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.validate_locale_translations_response import ValidateLocaleTranslationsResponse

class TestValidateLocaleTranslationsResponse(unittest.TestCase):
    """ValidateLocaleTranslationsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ValidateLocaleTranslationsResponse:
        """Test ValidateLocaleTranslationsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ValidateLocaleTranslationsResponse`
        """
        model = ValidateLocaleTranslationsResponse()
        if include_optional:
            return ValidateLocaleTranslationsResponse(
                invalid_translations = [
                    biotmed_settings_sdk.models.invalid_translation.InvalidTranslation(
                        translation_key = '', 
                        error = '', )
                    ]
            )
        else:
            return ValidateLocaleTranslationsResponse(
        )
        """

    def testValidateLocaleTranslationsResponse(self):
        """Test ValidateLocaleTranslationsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
