# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.interception_subscription_dto import InterceptionSubscriptionDto

class TestInterceptionSubscriptionDto(unittest.TestCase):
    """InterceptionSubscriptionDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InterceptionSubscriptionDto:
        """Test InterceptionSubscriptionDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InterceptionSubscriptionDto`
        """
        model = InterceptionSubscriptionDto()
        if include_optional:
            return InterceptionSubscriptionDto(
                type = 'PRE_REQUEST',
                api_id = '',
                entity_type_name = 'device',
                order = 56
            )
        else:
            return InterceptionSubscriptionDto(
                type = 'PRE_REQUEST',
        )
        """

    def testInterceptionSubscriptionDto(self):
        """Test InterceptionSubscriptionDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
