# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.api.plugin_v2_api_api import PluginV2APIApi


class TestPluginV2APIApi(unittest.TestCase):
    """PluginV2APIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PluginV2APIApi()

    def tearDown(self) -> None:
        pass

    def test_create(self) -> None:
        """Test case for create

        Create a new Plugin
        """
        pass

    def test_delete(self) -> None:
        """Test case for delete

        Delete Plugin
        """
        pass

    def test_get(self) -> None:
        """Test case for get

        Get plugin by name
        """
        pass

    def test_get_docker_repository_temp_credentials(self) -> None:
        """Test case for get_docker_repository_temp_credentials

        Get temporary credentials for the docker repository
        """
        pass

    def test_partial_update(self) -> None:
        """Test case for partial_update

        Update Plugin
        """
        pass

    def test_search(self) -> None:
        """Test case for search

        Search Plugin entities by filter
        """
        pass


if __name__ == '__main__':
    unittest.main()
