# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.update_template_request import UpdateTemplateRequest

class TestUpdateTemplateRequest(unittest.TestCase):
    """UpdateTemplateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateTemplateRequest:
        """Test UpdateTemplateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateTemplateRequest`
        """
        model = UpdateTemplateRequest()
        if include_optional:
            return UpdateTemplateRequest(
                display_name = '0',
                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua0',
                description = '0',
                owner_organization_id = '',
                analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                    name = '', ),
                force_update = True,
                custom_attributes = [
                    biotmed_settings_sdk.models.update_custom_attribute.UpdateCustomAttribute(
                        display_name = '0', 
                        phi = True, 
                        reference_configuration = biotmed_settings_sdk.models.reference_configuration.ReferenceConfiguration(
                            uniquely = True, 
                            referenced_side_attribute_name = '', 
                            referenced_side_attribute_display_name = '', 
                            valid_templates_to_reference = [
                                ''
                                ], 
                            entity_type = '', ), 
                        link_configuration = biotmed_settings_sdk.models.link_configuration.LinkConfiguration(
                            entity_type_name = '', 
                            template_id = '', 
                            attribute_id = '', ), 
                        name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua0', 
                        type = 'LABEL', 
                        validation = biotmed_settings_sdk.models.validation_definition_object.ValidationDefinitionObject(
                            mandatory = True, 
                            default_value = null, 
                            min = -9223372036854775808, 
                            max = -9223372036854775808, 
                            regex = '', ), 
                        numeric_meta_data = biotmed_settings_sdk.models.numeric_meta_data.NumericMetaData(
                            units = '', 
                            upper_range = -2147483648, 
                            lower_range = -2147483648, 
                            sub_type = 'INTEGER', ), 
                        analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                            name = '', ), 
                        id = '', 
                        selectable_values = [
                            biotmed_settings_sdk.models.selectable_value.SelectableValue(
                                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua', 
                                display_name = '', 
                                id = '', )
                            ], 
                        category = '', )
                    ],
                built_in_attributes = [
                    biotmed_settings_sdk.models.update_built_in_attribute.UpdateBuiltInAttribute(
                        id = '', 
                        display_name = '0', 
                        phi = True, 
                        reference_configuration = biotmed_settings_sdk.models.reference_configuration.ReferenceConfiguration(
                            uniquely = True, 
                            referenced_side_attribute_name = '', 
                            referenced_side_attribute_display_name = '', 
                            valid_templates_to_reference = [
                                ''
                                ], 
                            entity_type = '', ), 
                        link_configuration = biotmed_settings_sdk.models.link_configuration.LinkConfiguration(
                            entity_type_name = '', 
                            template_id = '', 
                            attribute_id = '', ), 
                        validation = biotmed_settings_sdk.models.validation_definition_object.ValidationDefinitionObject(
                            mandatory = True, 
                            default_value = null, 
                            min = -9223372036854775808, 
                            max = -9223372036854775808, 
                            regex = '', ), 
                        numeric_meta_data = biotmed_settings_sdk.models.numeric_meta_data.NumericMetaData(
                            units = '', 
                            upper_range = -2147483648, 
                            lower_range = -2147483648, 
                            sub_type = 'INTEGER', ), )
                    ],
                template_attributes = [
                    biotmed_settings_sdk.models.update_template_attribute.UpdateTemplateAttribute(
                        id = '', 
                        display_name = '0', 
                        phi = True, 
                        reference_configuration = biotmed_settings_sdk.models.reference_configuration.ReferenceConfiguration(
                            uniquely = True, 
                            referenced_side_attribute_name = '', 
                            referenced_side_attribute_display_name = '', 
                            valid_templates_to_reference = [
                                ''
                                ], 
                            entity_type = '', ), 
                        link_configuration = biotmed_settings_sdk.models.link_configuration.LinkConfiguration(
                            entity_type_name = '', 
                            template_id = '', 
                            attribute_id = '', ), 
                        value = null, 
                        organization_selection_configuration = biotmed_settings_sdk.models.organization_selection_configuration.OrganizationSelectionConfiguration(
                            selected = [
                                biotmed_settings_sdk.models.selected_organization.SelectedOrganization(
                                    id = '', )
                                ], 
                            all = True, ), )
                    ],
                parent_template_id = ''
            )
        else:
            return UpdateTemplateRequest(
                display_name = '0',
                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua0',
        )
        """

    def testUpdateTemplateRequest(self):
        """Test UpdateTemplateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
