# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.search_response_locale_translations_overview import SearchResponseLocaleTranslationsOverview

class TestSearchResponseLocaleTranslationsOverview(unittest.TestCase):
    """SearchResponseLocaleTranslationsOverview unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchResponseLocaleTranslationsOverview:
        """Test SearchResponseLocaleTranslationsOverview
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchResponseLocaleTranslationsOverview`
        """
        model = SearchResponseLocaleTranslationsOverview()
        if include_optional:
            return SearchResponseLocaleTranslationsOverview(
                data = [
                    biotmed_settings_sdk.models.locale_translations_overview.LocaleTranslationsOverview(
                        locale = '', 
                        coverage = biotmed_settings_sdk.models.locale_translations_coverage.LocaleTranslationsCoverage(
                            number_of_available_keys = 56, 
                            number_of_translated_keys = 56, ), 
                        last_translation_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                metadata = biotmed_settings_sdk.models.metadata.Metadata(
                    sort = [
                        biotmed_settings_sdk.models.order.Order(
                            prop = '', 
                            order = 'ASC', )
                        ], 
                    filter = {
                        'key' : biotmed_settings_sdk.models.filter_v2.FilterV2(
                            in = [
                                ''
                                ], 
                            eq = null, 
                            lt = 20, 
                            lte = 25, 
                            gt = 25, 
                            gte = 25, 
                            like = 'John', 
                            from = '2007-12-20', 
                            to = '2007-12-20', 
                            is_null = True, 
                            is_not_null = True, 
                            not = null, 
                            not_in = [
                                ''
                                ], )
                        }, 
                    page = biotmed_settings_sdk.models.page_metadata.PageMetadata(
                        total_results = 145, 
                        limit = 100, ), 
                    free_text_search = 'cat dog', )
            )
        else:
            return SearchResponseLocaleTranslationsOverview(
                data = [
                    biotmed_settings_sdk.models.locale_translations_overview.LocaleTranslationsOverview(
                        locale = '', 
                        coverage = biotmed_settings_sdk.models.locale_translations_coverage.LocaleTranslationsCoverage(
                            number_of_available_keys = 56, 
                            number_of_translated_keys = 56, ), 
                        last_translation_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                metadata = biotmed_settings_sdk.models.metadata.Metadata(
                    sort = [
                        biotmed_settings_sdk.models.order.Order(
                            prop = '', 
                            order = 'ASC', )
                        ], 
                    filter = {
                        'key' : biotmed_settings_sdk.models.filter_v2.FilterV2(
                            in = [
                                ''
                                ], 
                            eq = null, 
                            lt = 20, 
                            lte = 25, 
                            gt = 25, 
                            gte = 25, 
                            like = 'John', 
                            from = '2007-12-20', 
                            to = '2007-12-20', 
                            is_null = True, 
                            is_not_null = True, 
                            not = null, 
                            not_in = [
                                ''
                                ], )
                        }, 
                    page = biotmed_settings_sdk.models.page_metadata.PageMetadata(
                        total_results = 145, 
                        limit = 100, ), 
                    free_text_search = 'cat dog', ),
        )
        """

    def testSearchResponseLocaleTranslationsOverview(self):
        """Test SearchResponseLocaleTranslationsOverview"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
