# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.api.code_snippet_api_api import CodeSnippetAPIApi


class TestCodeSnippetAPIApi(unittest.TestCase):
    """CodeSnippetAPIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CodeSnippetAPIApi()

    def tearDown(self) -> None:
        pass

    def test_create_code_snippet(self) -> None:
        """Test case for create_code_snippet

        Create a new Code snippet
        """
        pass

    def test_delete_code_snippet(self) -> None:
        """Test case for delete_code_snippet

        Delete Code snippet
        """
        pass

    def test_get_code_snippet(self) -> None:
        """Test case for get_code_snippet

        Get Code snippet by ID
        """
        pass

    def test_search2(self) -> None:
        """Test case for search2

        Search Code snippet entities by filter
        """
        pass


if __name__ == '__main__':
    unittest.main()
