# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.basic_template_data import BasicTemplateData

class TestBasicTemplateData(unittest.TestCase):
    """BasicTemplateData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BasicTemplateData:
        """Test BasicTemplateData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BasicTemplateData`
        """
        model = BasicTemplateData()
        if include_optional:
            return BasicTemplateData(
                id = '',
                name = '',
                display_name = '',
                entity_type_name = ''
            )
        else:
            return BasicTemplateData(
        )
        """

    def testBasicTemplateData(self):
        """Test BasicTemplateData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
