# coding: utf-8

# flake8: noqa

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "2.3.40"

# Define package exports
__all__ = [
    "BackupAPIApi",
    "CodeSnippetAPIApi",
    "EntityAPIApi",
    "ExportImportConfigurationAPIApi",
    "HealthCheckAPIApi",
    "InterceptionConfigurationAPIApi",
    "LocaleAPIApi",
    "PluginV2APIApi",
    "SystemAPIApi",
    "TemplateAPIApi",
    "TranslationAPIApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AddLocaleRequest",
    "AttributeAnalyticsDbConfiguration",
    "AttributeIdentifier",
    "BackupRequest",
    "BackupResponse",
    "BaseLocale",
    "BaseSelectableValue",
    "BasicAttributeData",
    "BasicTemplateData",
    "BuiltInAttribute",
    "Category",
    "CodeSnippetResponse",
    "CreateBuiltInAttribute",
    "CreateCodeSnippetRequest",
    "CreateCustomAttribute",
    "CreatePluginRequest",
    "CreateTemplateAttribute",
    "CreateTemplateRequest",
    "Credentials",
    "CustomAttribute",
    "DockerRepositoryTempCredentialsResponse",
    "EntityNotifiableAction",
    "EntityType",
    "EntityTypeBuiltInAction",
    "EntityTypeBuiltInAttribute",
    "EntityTypeTemplateAttribute",
    "ErrorResponse",
    "ExportExecutionResponse",
    "ExportsMetadataResponse",
    "FileConfigurationMetadataResponse",
    "FilterV2",
    "GetCategoryResponse",
    "GetEntityTypesResponse",
    "GetNotifiableActions",
    "GetTemplateResponse",
    "ImportExecutionResponse",
    "InterceptionConfigurationResponse",
    "InterceptionSubscriptionDto",
    "InvalidTranslation",
    "JsonNullableListCorsAllowedHttpMethodEnum",
    "JsonNullableListInterceptionSubscriptionDto",
    "JsonNullableListNotificationSubscriptionDto",
    "JsonNullableListString",
    "JsonNullableSetBaseLocale",
    "LinkConfiguration",
    "LocaleTranslationsCoverage",
    "LocaleTranslationsOverview",
    "LocalesResponse",
    "Metadata",
    "NotificationSubscriptionDto",
    "NumericMetaData",
    "Order",
    "OrganizationSelection",
    "OrganizationSelectionConfiguration",
    "PageMetadata",
    "ParentTemplateResponse",
    "PartialPluginCorsConfig",
    "PartialUpdatePluginRequest",
    "PartialUpdateSubscriptionDto",
    "PluginCorsConfig",
    "PluginResponse",
    "PrimaryAdministrator",
    "ReferenceConfiguration",
    "ResetSystemRequest",
    "RestoreResponse",
    "SearchRequestV2",
    "SearchResponseBackupResponse",
    "SearchResponseCodeSnippetResponse",
    "SearchResponseEntityType",
    "SearchResponseGetTemplateResponse",
    "SearchResponseInterceptionConfigurationResponse",
    "SearchResponseLocaleTranslationsOverview",
    "SearchResponsePluginResponse",
    "SearchResponseRestoreResponse",
    "SearchResponseTemplateMinimizedResponse",
    "SelectableValue",
    "SelectedOrganization",
    "StartExportConfigurationRequest",
    "StartImportConfigurationRequest",
    "SubscriptionDto",
    "SystemPropertiesResponse",
    "TemplateAnalyticsDbConfiguration",
    "TemplateAttribute",
    "TemplateMinimizedResponse",
    "TemplateOverviewResponse",
    "TemplateStatistics",
    "UpdateBuiltInAttribute",
    "UpdateCustomAttribute",
    "UpdateLocaleTranslationsResponse",
    "UpdateLocalesRequest",
    "UpdateTemplateAttribute",
    "UpdateTemplateRequest",
    "ValidateLocaleTranslationsResponse",
    "ValidationDefinitionMetadataObject",
    "ValidationDefinitionObject",
    "VersionResponse",
]

if __import__("typing").TYPE_CHECKING:
    # import apis into sdk package
    from biotmed_settings_sdk.api.backup_api_api import BackupAPIApi as BackupAPIApi
    from biotmed_settings_sdk.api.code_snippet_api_api import CodeSnippetAPIApi as CodeSnippetAPIApi
    from biotmed_settings_sdk.api.entity_api_api import EntityAPIApi as EntityAPIApi
    from biotmed_settings_sdk.api.export_import_configuration_api_api import ExportImportConfigurationAPIApi as ExportImportConfigurationAPIApi
    from biotmed_settings_sdk.api.health_check_api_api import HealthCheckAPIApi as HealthCheckAPIApi
    from biotmed_settings_sdk.api.interception_configuration_api_api import InterceptionConfigurationAPIApi as InterceptionConfigurationAPIApi
    from biotmed_settings_sdk.api.locale_api_api import LocaleAPIApi as LocaleAPIApi
    from biotmed_settings_sdk.api.plugin_v2_api_api import PluginV2APIApi as PluginV2APIApi
    from biotmed_settings_sdk.api.system_api_api import SystemAPIApi as SystemAPIApi
    from biotmed_settings_sdk.api.template_api_api import TemplateAPIApi as TemplateAPIApi
    from biotmed_settings_sdk.api.translation_api_api import TranslationAPIApi as TranslationAPIApi
    
    # import ApiClient
    from biotmed_settings_sdk.api_response import ApiResponse as ApiResponse
    from biotmed_settings_sdk.api_client import ApiClient as ApiClient
    from biotmed_settings_sdk.configuration import Configuration as Configuration
    from biotmed_settings_sdk.exceptions import OpenApiException as OpenApiException
    from biotmed_settings_sdk.exceptions import ApiTypeError as ApiTypeError
    from biotmed_settings_sdk.exceptions import ApiValueError as ApiValueError
    from biotmed_settings_sdk.exceptions import ApiKeyError as ApiKeyError
    from biotmed_settings_sdk.exceptions import ApiAttributeError as ApiAttributeError
    from biotmed_settings_sdk.exceptions import ApiException as ApiException
    
    # import models into sdk package
    from biotmed_settings_sdk.models.add_locale_request import AddLocaleRequest as AddLocaleRequest
    from biotmed_settings_sdk.models.attribute_analytics_db_configuration import AttributeAnalyticsDbConfiguration as AttributeAnalyticsDbConfiguration
    from biotmed_settings_sdk.models.attribute_identifier import AttributeIdentifier as AttributeIdentifier
    from biotmed_settings_sdk.models.backup_request import BackupRequest as BackupRequest
    from biotmed_settings_sdk.models.backup_response import BackupResponse as BackupResponse
    from biotmed_settings_sdk.models.base_locale import BaseLocale as BaseLocale
    from biotmed_settings_sdk.models.base_selectable_value import BaseSelectableValue as BaseSelectableValue
    from biotmed_settings_sdk.models.basic_attribute_data import BasicAttributeData as BasicAttributeData
    from biotmed_settings_sdk.models.basic_template_data import BasicTemplateData as BasicTemplateData
    from biotmed_settings_sdk.models.built_in_attribute import BuiltInAttribute as BuiltInAttribute
    from biotmed_settings_sdk.models.category import Category as Category
    from biotmed_settings_sdk.models.code_snippet_response import CodeSnippetResponse as CodeSnippetResponse
    from biotmed_settings_sdk.models.create_built_in_attribute import CreateBuiltInAttribute as CreateBuiltInAttribute
    from biotmed_settings_sdk.models.create_code_snippet_request import CreateCodeSnippetRequest as CreateCodeSnippetRequest
    from biotmed_settings_sdk.models.create_custom_attribute import CreateCustomAttribute as CreateCustomAttribute
    from biotmed_settings_sdk.models.create_plugin_request import CreatePluginRequest as CreatePluginRequest
    from biotmed_settings_sdk.models.create_template_attribute import CreateTemplateAttribute as CreateTemplateAttribute
    from biotmed_settings_sdk.models.create_template_request import CreateTemplateRequest as CreateTemplateRequest
    from biotmed_settings_sdk.models.credentials import Credentials as Credentials
    from biotmed_settings_sdk.models.custom_attribute import CustomAttribute as CustomAttribute
    from biotmed_settings_sdk.models.docker_repository_temp_credentials_response import DockerRepositoryTempCredentialsResponse as DockerRepositoryTempCredentialsResponse
    from biotmed_settings_sdk.models.entity_notifiable_action import EntityNotifiableAction as EntityNotifiableAction
    from biotmed_settings_sdk.models.entity_type import EntityType as EntityType
    from biotmed_settings_sdk.models.entity_type_built_in_action import EntityTypeBuiltInAction as EntityTypeBuiltInAction
    from biotmed_settings_sdk.models.entity_type_built_in_attribute import EntityTypeBuiltInAttribute as EntityTypeBuiltInAttribute
    from biotmed_settings_sdk.models.entity_type_template_attribute import EntityTypeTemplateAttribute as EntityTypeTemplateAttribute
    from biotmed_settings_sdk.models.error_response import ErrorResponse as ErrorResponse
    from biotmed_settings_sdk.models.export_execution_response import ExportExecutionResponse as ExportExecutionResponse
    from biotmed_settings_sdk.models.exports_metadata_response import ExportsMetadataResponse as ExportsMetadataResponse
    from biotmed_settings_sdk.models.file_configuration_metadata_response import FileConfigurationMetadataResponse as FileConfigurationMetadataResponse
    from biotmed_settings_sdk.models.filter_v2 import FilterV2 as FilterV2
    from biotmed_settings_sdk.models.get_category_response import GetCategoryResponse as GetCategoryResponse
    from biotmed_settings_sdk.models.get_entity_types_response import GetEntityTypesResponse as GetEntityTypesResponse
    from biotmed_settings_sdk.models.get_notifiable_actions import GetNotifiableActions as GetNotifiableActions
    from biotmed_settings_sdk.models.get_template_response import GetTemplateResponse as GetTemplateResponse
    from biotmed_settings_sdk.models.import_execution_response import ImportExecutionResponse as ImportExecutionResponse
    from biotmed_settings_sdk.models.interception_configuration_response import InterceptionConfigurationResponse as InterceptionConfigurationResponse
    from biotmed_settings_sdk.models.interception_subscription_dto import InterceptionSubscriptionDto as InterceptionSubscriptionDto
    from biotmed_settings_sdk.models.invalid_translation import InvalidTranslation as InvalidTranslation
    from biotmed_settings_sdk.models.json_nullable_list_cors_allowed_http_method_enum import JsonNullableListCorsAllowedHttpMethodEnum as JsonNullableListCorsAllowedHttpMethodEnum
    from biotmed_settings_sdk.models.json_nullable_list_interception_subscription_dto import JsonNullableListInterceptionSubscriptionDto as JsonNullableListInterceptionSubscriptionDto
    from biotmed_settings_sdk.models.json_nullable_list_notification_subscription_dto import JsonNullableListNotificationSubscriptionDto as JsonNullableListNotificationSubscriptionDto
    from biotmed_settings_sdk.models.json_nullable_list_string import JsonNullableListString as JsonNullableListString
    from biotmed_settings_sdk.models.json_nullable_set_base_locale import JsonNullableSetBaseLocale as JsonNullableSetBaseLocale
    from biotmed_settings_sdk.models.link_configuration import LinkConfiguration as LinkConfiguration
    from biotmed_settings_sdk.models.locale_translations_coverage import LocaleTranslationsCoverage as LocaleTranslationsCoverage
    from biotmed_settings_sdk.models.locale_translations_overview import LocaleTranslationsOverview as LocaleTranslationsOverview
    from biotmed_settings_sdk.models.locales_response import LocalesResponse as LocalesResponse
    from biotmed_settings_sdk.models.metadata import Metadata as Metadata
    from biotmed_settings_sdk.models.notification_subscription_dto import NotificationSubscriptionDto as NotificationSubscriptionDto
    from biotmed_settings_sdk.models.numeric_meta_data import NumericMetaData as NumericMetaData
    from biotmed_settings_sdk.models.order import Order as Order
    from biotmed_settings_sdk.models.organization_selection import OrganizationSelection as OrganizationSelection
    from biotmed_settings_sdk.models.organization_selection_configuration import OrganizationSelectionConfiguration as OrganizationSelectionConfiguration
    from biotmed_settings_sdk.models.page_metadata import PageMetadata as PageMetadata
    from biotmed_settings_sdk.models.parent_template_response import ParentTemplateResponse as ParentTemplateResponse
    from biotmed_settings_sdk.models.partial_plugin_cors_config import PartialPluginCorsConfig as PartialPluginCorsConfig
    from biotmed_settings_sdk.models.partial_update_plugin_request import PartialUpdatePluginRequest as PartialUpdatePluginRequest
    from biotmed_settings_sdk.models.partial_update_subscription_dto import PartialUpdateSubscriptionDto as PartialUpdateSubscriptionDto
    from biotmed_settings_sdk.models.plugin_cors_config import PluginCorsConfig as PluginCorsConfig
    from biotmed_settings_sdk.models.plugin_response import PluginResponse as PluginResponse
    from biotmed_settings_sdk.models.primary_administrator import PrimaryAdministrator as PrimaryAdministrator
    from biotmed_settings_sdk.models.reference_configuration import ReferenceConfiguration as ReferenceConfiguration
    from biotmed_settings_sdk.models.reset_system_request import ResetSystemRequest as ResetSystemRequest
    from biotmed_settings_sdk.models.restore_response import RestoreResponse as RestoreResponse
    from biotmed_settings_sdk.models.search_request_v2 import SearchRequestV2 as SearchRequestV2
    from biotmed_settings_sdk.models.search_response_backup_response import SearchResponseBackupResponse as SearchResponseBackupResponse
    from biotmed_settings_sdk.models.search_response_code_snippet_response import SearchResponseCodeSnippetResponse as SearchResponseCodeSnippetResponse
    from biotmed_settings_sdk.models.search_response_entity_type import SearchResponseEntityType as SearchResponseEntityType
    from biotmed_settings_sdk.models.search_response_get_template_response import SearchResponseGetTemplateResponse as SearchResponseGetTemplateResponse
    from biotmed_settings_sdk.models.search_response_interception_configuration_response import SearchResponseInterceptionConfigurationResponse as SearchResponseInterceptionConfigurationResponse
    from biotmed_settings_sdk.models.search_response_locale_translations_overview import SearchResponseLocaleTranslationsOverview as SearchResponseLocaleTranslationsOverview
    from biotmed_settings_sdk.models.search_response_plugin_response import SearchResponsePluginResponse as SearchResponsePluginResponse
    from biotmed_settings_sdk.models.search_response_restore_response import SearchResponseRestoreResponse as SearchResponseRestoreResponse
    from biotmed_settings_sdk.models.search_response_template_minimized_response import SearchResponseTemplateMinimizedResponse as SearchResponseTemplateMinimizedResponse
    from biotmed_settings_sdk.models.selectable_value import SelectableValue as SelectableValue
    from biotmed_settings_sdk.models.selected_organization import SelectedOrganization as SelectedOrganization
    from biotmed_settings_sdk.models.start_export_configuration_request import StartExportConfigurationRequest as StartExportConfigurationRequest
    from biotmed_settings_sdk.models.start_import_configuration_request import StartImportConfigurationRequest as StartImportConfigurationRequest
    from biotmed_settings_sdk.models.subscription_dto import SubscriptionDto as SubscriptionDto
    from biotmed_settings_sdk.models.system_properties_response import SystemPropertiesResponse as SystemPropertiesResponse
    from biotmed_settings_sdk.models.template_analytics_db_configuration import TemplateAnalyticsDbConfiguration as TemplateAnalyticsDbConfiguration
    from biotmed_settings_sdk.models.template_attribute import TemplateAttribute as TemplateAttribute
    from biotmed_settings_sdk.models.template_minimized_response import TemplateMinimizedResponse as TemplateMinimizedResponse
    from biotmed_settings_sdk.models.template_overview_response import TemplateOverviewResponse as TemplateOverviewResponse
    from biotmed_settings_sdk.models.template_statistics import TemplateStatistics as TemplateStatistics
    from biotmed_settings_sdk.models.update_built_in_attribute import UpdateBuiltInAttribute as UpdateBuiltInAttribute
    from biotmed_settings_sdk.models.update_custom_attribute import UpdateCustomAttribute as UpdateCustomAttribute
    from biotmed_settings_sdk.models.update_locale_translations_response import UpdateLocaleTranslationsResponse as UpdateLocaleTranslationsResponse
    from biotmed_settings_sdk.models.update_locales_request import UpdateLocalesRequest as UpdateLocalesRequest
    from biotmed_settings_sdk.models.update_template_attribute import UpdateTemplateAttribute as UpdateTemplateAttribute
    from biotmed_settings_sdk.models.update_template_request import UpdateTemplateRequest as UpdateTemplateRequest
    from biotmed_settings_sdk.models.validate_locale_translations_response import ValidateLocaleTranslationsResponse as ValidateLocaleTranslationsResponse
    from biotmed_settings_sdk.models.validation_definition_metadata_object import ValidationDefinitionMetadataObject as ValidationDefinitionMetadataObject
    from biotmed_settings_sdk.models.validation_definition_object import ValidationDefinitionObject as ValidationDefinitionObject
    from biotmed_settings_sdk.models.version_response import VersionResponse as VersionResponse
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            ("__version__", __version__),
            ("__all__", __all__),
            """# import apis into sdk package
from biotmed_settings_sdk.api.backup_api_api import BackupAPIApi as BackupAPIApi
from biotmed_settings_sdk.api.code_snippet_api_api import CodeSnippetAPIApi as CodeSnippetAPIApi
from biotmed_settings_sdk.api.entity_api_api import EntityAPIApi as EntityAPIApi
from biotmed_settings_sdk.api.export_import_configuration_api_api import ExportImportConfigurationAPIApi as ExportImportConfigurationAPIApi
from biotmed_settings_sdk.api.health_check_api_api import HealthCheckAPIApi as HealthCheckAPIApi
from biotmed_settings_sdk.api.interception_configuration_api_api import InterceptionConfigurationAPIApi as InterceptionConfigurationAPIApi
from biotmed_settings_sdk.api.locale_api_api import LocaleAPIApi as LocaleAPIApi
from biotmed_settings_sdk.api.plugin_v2_api_api import PluginV2APIApi as PluginV2APIApi
from biotmed_settings_sdk.api.system_api_api import SystemAPIApi as SystemAPIApi
from biotmed_settings_sdk.api.template_api_api import TemplateAPIApi as TemplateAPIApi
from biotmed_settings_sdk.api.translation_api_api import TranslationAPIApi as TranslationAPIApi

# import ApiClient
from biotmed_settings_sdk.api_response import ApiResponse as ApiResponse
from biotmed_settings_sdk.api_client import ApiClient as ApiClient
from biotmed_settings_sdk.configuration import Configuration as Configuration
from biotmed_settings_sdk.exceptions import OpenApiException as OpenApiException
from biotmed_settings_sdk.exceptions import ApiTypeError as ApiTypeError
from biotmed_settings_sdk.exceptions import ApiValueError as ApiValueError
from biotmed_settings_sdk.exceptions import ApiKeyError as ApiKeyError
from biotmed_settings_sdk.exceptions import ApiAttributeError as ApiAttributeError
from biotmed_settings_sdk.exceptions import ApiException as ApiException

# import models into sdk package
from biotmed_settings_sdk.models.add_locale_request import AddLocaleRequest as AddLocaleRequest
from biotmed_settings_sdk.models.attribute_analytics_db_configuration import AttributeAnalyticsDbConfiguration as AttributeAnalyticsDbConfiguration
from biotmed_settings_sdk.models.attribute_identifier import AttributeIdentifier as AttributeIdentifier
from biotmed_settings_sdk.models.backup_request import BackupRequest as BackupRequest
from biotmed_settings_sdk.models.backup_response import BackupResponse as BackupResponse
from biotmed_settings_sdk.models.base_locale import BaseLocale as BaseLocale
from biotmed_settings_sdk.models.base_selectable_value import BaseSelectableValue as BaseSelectableValue
from biotmed_settings_sdk.models.basic_attribute_data import BasicAttributeData as BasicAttributeData
from biotmed_settings_sdk.models.basic_template_data import BasicTemplateData as BasicTemplateData
from biotmed_settings_sdk.models.built_in_attribute import BuiltInAttribute as BuiltInAttribute
from biotmed_settings_sdk.models.category import Category as Category
from biotmed_settings_sdk.models.code_snippet_response import CodeSnippetResponse as CodeSnippetResponse
from biotmed_settings_sdk.models.create_built_in_attribute import CreateBuiltInAttribute as CreateBuiltInAttribute
from biotmed_settings_sdk.models.create_code_snippet_request import CreateCodeSnippetRequest as CreateCodeSnippetRequest
from biotmed_settings_sdk.models.create_custom_attribute import CreateCustomAttribute as CreateCustomAttribute
from biotmed_settings_sdk.models.create_plugin_request import CreatePluginRequest as CreatePluginRequest
from biotmed_settings_sdk.models.create_template_attribute import CreateTemplateAttribute as CreateTemplateAttribute
from biotmed_settings_sdk.models.create_template_request import CreateTemplateRequest as CreateTemplateRequest
from biotmed_settings_sdk.models.credentials import Credentials as Credentials
from biotmed_settings_sdk.models.custom_attribute import CustomAttribute as CustomAttribute
from biotmed_settings_sdk.models.docker_repository_temp_credentials_response import DockerRepositoryTempCredentialsResponse as DockerRepositoryTempCredentialsResponse
from biotmed_settings_sdk.models.entity_notifiable_action import EntityNotifiableAction as EntityNotifiableAction
from biotmed_settings_sdk.models.entity_type import EntityType as EntityType
from biotmed_settings_sdk.models.entity_type_built_in_action import EntityTypeBuiltInAction as EntityTypeBuiltInAction
from biotmed_settings_sdk.models.entity_type_built_in_attribute import EntityTypeBuiltInAttribute as EntityTypeBuiltInAttribute
from biotmed_settings_sdk.models.entity_type_template_attribute import EntityTypeTemplateAttribute as EntityTypeTemplateAttribute
from biotmed_settings_sdk.models.error_response import ErrorResponse as ErrorResponse
from biotmed_settings_sdk.models.export_execution_response import ExportExecutionResponse as ExportExecutionResponse
from biotmed_settings_sdk.models.exports_metadata_response import ExportsMetadataResponse as ExportsMetadataResponse
from biotmed_settings_sdk.models.file_configuration_metadata_response import FileConfigurationMetadataResponse as FileConfigurationMetadataResponse
from biotmed_settings_sdk.models.filter_v2 import FilterV2 as FilterV2
from biotmed_settings_sdk.models.get_category_response import GetCategoryResponse as GetCategoryResponse
from biotmed_settings_sdk.models.get_entity_types_response import GetEntityTypesResponse as GetEntityTypesResponse
from biotmed_settings_sdk.models.get_notifiable_actions import GetNotifiableActions as GetNotifiableActions
from biotmed_settings_sdk.models.get_template_response import GetTemplateResponse as GetTemplateResponse
from biotmed_settings_sdk.models.import_execution_response import ImportExecutionResponse as ImportExecutionResponse
from biotmed_settings_sdk.models.interception_configuration_response import InterceptionConfigurationResponse as InterceptionConfigurationResponse
from biotmed_settings_sdk.models.interception_subscription_dto import InterceptionSubscriptionDto as InterceptionSubscriptionDto
from biotmed_settings_sdk.models.invalid_translation import InvalidTranslation as InvalidTranslation
from biotmed_settings_sdk.models.json_nullable_list_cors_allowed_http_method_enum import JsonNullableListCorsAllowedHttpMethodEnum as JsonNullableListCorsAllowedHttpMethodEnum
from biotmed_settings_sdk.models.json_nullable_list_interception_subscription_dto import JsonNullableListInterceptionSubscriptionDto as JsonNullableListInterceptionSubscriptionDto
from biotmed_settings_sdk.models.json_nullable_list_notification_subscription_dto import JsonNullableListNotificationSubscriptionDto as JsonNullableListNotificationSubscriptionDto
from biotmed_settings_sdk.models.json_nullable_list_string import JsonNullableListString as JsonNullableListString
from biotmed_settings_sdk.models.json_nullable_set_base_locale import JsonNullableSetBaseLocale as JsonNullableSetBaseLocale
from biotmed_settings_sdk.models.link_configuration import LinkConfiguration as LinkConfiguration
from biotmed_settings_sdk.models.locale_translations_coverage import LocaleTranslationsCoverage as LocaleTranslationsCoverage
from biotmed_settings_sdk.models.locale_translations_overview import LocaleTranslationsOverview as LocaleTranslationsOverview
from biotmed_settings_sdk.models.locales_response import LocalesResponse as LocalesResponse
from biotmed_settings_sdk.models.metadata import Metadata as Metadata
from biotmed_settings_sdk.models.notification_subscription_dto import NotificationSubscriptionDto as NotificationSubscriptionDto
from biotmed_settings_sdk.models.numeric_meta_data import NumericMetaData as NumericMetaData
from biotmed_settings_sdk.models.order import Order as Order
from biotmed_settings_sdk.models.organization_selection import OrganizationSelection as OrganizationSelection
from biotmed_settings_sdk.models.organization_selection_configuration import OrganizationSelectionConfiguration as OrganizationSelectionConfiguration
from biotmed_settings_sdk.models.page_metadata import PageMetadata as PageMetadata
from biotmed_settings_sdk.models.parent_template_response import ParentTemplateResponse as ParentTemplateResponse
from biotmed_settings_sdk.models.partial_plugin_cors_config import PartialPluginCorsConfig as PartialPluginCorsConfig
from biotmed_settings_sdk.models.partial_update_plugin_request import PartialUpdatePluginRequest as PartialUpdatePluginRequest
from biotmed_settings_sdk.models.partial_update_subscription_dto import PartialUpdateSubscriptionDto as PartialUpdateSubscriptionDto
from biotmed_settings_sdk.models.plugin_cors_config import PluginCorsConfig as PluginCorsConfig
from biotmed_settings_sdk.models.plugin_response import PluginResponse as PluginResponse
from biotmed_settings_sdk.models.primary_administrator import PrimaryAdministrator as PrimaryAdministrator
from biotmed_settings_sdk.models.reference_configuration import ReferenceConfiguration as ReferenceConfiguration
from biotmed_settings_sdk.models.reset_system_request import ResetSystemRequest as ResetSystemRequest
from biotmed_settings_sdk.models.restore_response import RestoreResponse as RestoreResponse
from biotmed_settings_sdk.models.search_request_v2 import SearchRequestV2 as SearchRequestV2
from biotmed_settings_sdk.models.search_response_backup_response import SearchResponseBackupResponse as SearchResponseBackupResponse
from biotmed_settings_sdk.models.search_response_code_snippet_response import SearchResponseCodeSnippetResponse as SearchResponseCodeSnippetResponse
from biotmed_settings_sdk.models.search_response_entity_type import SearchResponseEntityType as SearchResponseEntityType
from biotmed_settings_sdk.models.search_response_get_template_response import SearchResponseGetTemplateResponse as SearchResponseGetTemplateResponse
from biotmed_settings_sdk.models.search_response_interception_configuration_response import SearchResponseInterceptionConfigurationResponse as SearchResponseInterceptionConfigurationResponse
from biotmed_settings_sdk.models.search_response_locale_translations_overview import SearchResponseLocaleTranslationsOverview as SearchResponseLocaleTranslationsOverview
from biotmed_settings_sdk.models.search_response_plugin_response import SearchResponsePluginResponse as SearchResponsePluginResponse
from biotmed_settings_sdk.models.search_response_restore_response import SearchResponseRestoreResponse as SearchResponseRestoreResponse
from biotmed_settings_sdk.models.search_response_template_minimized_response import SearchResponseTemplateMinimizedResponse as SearchResponseTemplateMinimizedResponse
from biotmed_settings_sdk.models.selectable_value import SelectableValue as SelectableValue
from biotmed_settings_sdk.models.selected_organization import SelectedOrganization as SelectedOrganization
from biotmed_settings_sdk.models.start_export_configuration_request import StartExportConfigurationRequest as StartExportConfigurationRequest
from biotmed_settings_sdk.models.start_import_configuration_request import StartImportConfigurationRequest as StartImportConfigurationRequest
from biotmed_settings_sdk.models.subscription_dto import SubscriptionDto as SubscriptionDto
from biotmed_settings_sdk.models.system_properties_response import SystemPropertiesResponse as SystemPropertiesResponse
from biotmed_settings_sdk.models.template_analytics_db_configuration import TemplateAnalyticsDbConfiguration as TemplateAnalyticsDbConfiguration
from biotmed_settings_sdk.models.template_attribute import TemplateAttribute as TemplateAttribute
from biotmed_settings_sdk.models.template_minimized_response import TemplateMinimizedResponse as TemplateMinimizedResponse
from biotmed_settings_sdk.models.template_overview_response import TemplateOverviewResponse as TemplateOverviewResponse
from biotmed_settings_sdk.models.template_statistics import TemplateStatistics as TemplateStatistics
from biotmed_settings_sdk.models.update_built_in_attribute import UpdateBuiltInAttribute as UpdateBuiltInAttribute
from biotmed_settings_sdk.models.update_custom_attribute import UpdateCustomAttribute as UpdateCustomAttribute
from biotmed_settings_sdk.models.update_locale_translations_response import UpdateLocaleTranslationsResponse as UpdateLocaleTranslationsResponse
from biotmed_settings_sdk.models.update_locales_request import UpdateLocalesRequest as UpdateLocalesRequest
from biotmed_settings_sdk.models.update_template_attribute import UpdateTemplateAttribute as UpdateTemplateAttribute
from biotmed_settings_sdk.models.update_template_request import UpdateTemplateRequest as UpdateTemplateRequest
from biotmed_settings_sdk.models.validate_locale_translations_response import ValidateLocaleTranslationsResponse as ValidateLocaleTranslationsResponse
from biotmed_settings_sdk.models.validation_definition_metadata_object import ValidationDefinitionMetadataObject as ValidationDefinitionMetadataObject
from biotmed_settings_sdk.models.validation_definition_object import ValidationDefinitionObject as ValidationDefinitionObject
from biotmed_settings_sdk.models.version_response import VersionResponse as VersionResponse

""",
            name=__name__,
            doc=__doc__,
        )
    )
