# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.get_template_response import GetTemplateResponse

class TestGetTemplateResponse(unittest.TestCase):
    """GetTemplateResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetTemplateResponse:
        """Test GetTemplateResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetTemplateResponse`
        """
        model = GetTemplateResponse()
        if include_optional:
            return GetTemplateResponse(
                display_name = '0',
                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua0',
                description = '0',
                owner_organization_id = '',
                analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                    name = '', ),
                id = '',
                entity_type_name = '',
                removable = True,
                creation_time = '2007-12-20T10:15:30Z',
                last_modified_time = '2007-12-20T10:15:30Z',
                parent_template = biotmed_settings_sdk.models.parent_template_response.ParentTemplateResponse(
                    id = '', 
                    display_name = '', 
                    name = '', ),
                parent_template_id = '',
                custom_attributes = [
                    biotmed_settings_sdk.models.custom_attribute.CustomAttribute(
                        display_name = '0', 
                        phi = True, 
                        reference_configuration = biotmed_settings_sdk.models.reference_configuration.ReferenceConfiguration(
                            uniquely = True, 
                            referenced_side_attribute_name = '', 
                            referenced_side_attribute_display_name = '', 
                            valid_templates_to_reference = [
                                ''
                                ], 
                            entity_type = '', ), 
                        link_configuration = biotmed_settings_sdk.models.link_configuration.LinkConfiguration(
                            entity_type_name = '', 
                            template_id = '', 
                            attribute_id = '', ), 
                        name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua0', 
                        type = 'LABEL', 
                        validation = biotmed_settings_sdk.models.validation_definition_object.ValidationDefinitionObject(
                            mandatory = True, 
                            default_value = null, 
                            min = -9223372036854775808, 
                            max = -9223372036854775808, 
                            regex = '', ), 
                        numeric_meta_data = biotmed_settings_sdk.models.numeric_meta_data.NumericMetaData(
                            units = '', 
                            upper_range = -2147483648, 
                            lower_range = -2147483648, 
                            sub_type = 'INTEGER', ), 
                        analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                            name = '', ), 
                        id = '', 
                        selectable_values = [
                            biotmed_settings_sdk.models.selectable_value.SelectableValue(
                                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua', 
                                display_name = '', 
                                id = '', )
                            ], 
                        category = biotmed_settings_sdk.models.category.Category(
                            name = '', 
                            display_name = '', ), 
                        base_path = '', 
                        type_enum = 'LABEL', )
                    ],
                built_in_attributes = [
                    biotmed_settings_sdk.models.built_in_attribute.BuiltInAttribute(
                        name = '', 
                        base_path = '', 
                        id = '', 
                        display_name = '0', 
                        phi = True, 
                        reference_configuration = biotmed_settings_sdk.models.reference_configuration.ReferenceConfiguration(
                            uniquely = True, 
                            referenced_side_attribute_name = '', 
                            referenced_side_attribute_display_name = '', 
                            valid_templates_to_reference = [
                                ''
                                ], 
                            entity_type = '', ), 
                        link_configuration = biotmed_settings_sdk.models.link_configuration.LinkConfiguration(
                            entity_type_name = '', 
                            template_id = '', 
                            attribute_id = '', ), 
                        validation = biotmed_settings_sdk.models.validation_definition_object.ValidationDefinitionObject(
                            mandatory = True, 
                            default_value = null, 
                            min = -9223372036854775808, 
                            max = -9223372036854775808, 
                            regex = '', ), 
                        numeric_meta_data = biotmed_settings_sdk.models.numeric_meta_data.NumericMetaData(
                            units = '', 
                            upper_range = -2147483648, 
                            lower_range = -2147483648, 
                            sub_type = 'INTEGER', ), 
                        type = 'LABEL', 
                        category = biotmed_settings_sdk.models.category.Category(
                            name = '', 
                            display_name = '', ), 
                        validation_metadata = biotmed_settings_sdk.models.validation_definition_metadata_object.ValidationDefinitionMetadataObject(
                            mandatory_read_only = True, 
                            system_mandatory = True, 
                            phi_read_only = True, ), 
                        selectable_values = [
                            biotmed_settings_sdk.models.base_selectable_value.BaseSelectableValue(
                                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua', 
                                display_name = '', )
                            ], 
                        read_only = True, 
                        analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                            name = '', ), 
                        type_enum = 'LABEL', )
                    ],
                template_attributes = [
                    biotmed_settings_sdk.models.template_attribute.TemplateAttribute(
                        name = '', 
                        base_path = '', 
                        id = '', 
                        display_name = '0', 
                        phi = True, 
                        reference_configuration = biotmed_settings_sdk.models.reference_configuration.ReferenceConfiguration(
                            uniquely = True, 
                            referenced_side_attribute_name = '', 
                            referenced_side_attribute_display_name = '', 
                            valid_templates_to_reference = [
                                ''
                                ], 
                            entity_type = '', ), 
                        link_configuration = biotmed_settings_sdk.models.link_configuration.LinkConfiguration(
                            entity_type_name = '', 
                            template_id = '', 
                            attribute_id = '', ), 
                        value = null, 
                        type = 'LABEL', 
                        category = biotmed_settings_sdk.models.category.Category(
                            name = '', 
                            display_name = '', ), 
                        selectable_values = [
                            biotmed_settings_sdk.models.base_selectable_value.BaseSelectableValue(
                                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua', 
                                display_name = '', )
                            ], 
                        validation = biotmed_settings_sdk.models.validation_definition_object.ValidationDefinitionObject(
                            mandatory = True, 
                            default_value = null, 
                            min = -9223372036854775808, 
                            max = -9223372036854775808, 
                            regex = '', ), 
                        numeric_meta_data = biotmed_settings_sdk.models.numeric_meta_data.NumericMetaData(
                            units = '', 
                            upper_range = -2147483648, 
                            lower_range = -2147483648, 
                            sub_type = 'INTEGER', ), 
                        organization_selection = biotmed_settings_sdk.models.organization_selection.OrganizationSelection(
                            allowed = True, 
                            configuration = biotmed_settings_sdk.models.organization_selection_configuration.OrganizationSelectionConfiguration(
                                selected = [
                                    biotmed_settings_sdk.models.selected_organization.SelectedOrganization(
                                        id = '', )
                                    ], 
                                all = True, ), ), 
                        type_enum = 'LABEL', )
                    ]
            )
        else:
            return GetTemplateResponse(
                display_name = '0',
                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua0',
                creation_time = '2007-12-20T10:15:30Z',
                last_modified_time = '2007-12-20T10:15:30Z',
        )
        """

    def testGetTemplateResponse(self):
        """Test GetTemplateResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
