# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.get_entity_types_response import GetEntityTypesResponse

class TestGetEntityTypesResponse(unittest.TestCase):
    """GetEntityTypesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetEntityTypesResponse:
        """Test GetEntityTypesResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetEntityTypesResponse`
        """
        model = GetEntityTypesResponse()
        if include_optional:
            return GetEntityTypesResponse(
                entity_types = [
                    biotmed_settings_sdk.models.entity_type.EntityType(
                        name = '', 
                        display_name = '', 
                        built_in_actions = [
                            biotmed_settings_sdk.models.entity_type_built_in_action.EntityTypeBuiltInAction(
                                name = '', 
                                base_path = '', 
                                display_name = '', 
                                enable_notification = True, 
                                enable_log = True, 
                                timeout_in_seconds = 56, 
                                source = '', 
                                category = biotmed_settings_sdk.models.category.Category(
                                    name = '', 
                                    display_name = '', ), )
                            ], 
                        children = [
                            biotmed_settings_sdk.models.entity_type.EntityType(
                                name = '', 
                                display_name = '', 
                                attribute_categories = [
                                    biotmed_settings_sdk.models.get_category_response.GetCategoryResponse(
                                        name = '', 
                                        display_name = '', 
                                        built_in_supported_types = [
                                            'LABEL'
                                            ], 
                                        custom_supported_types = [
                                            'LABEL'
                                            ], 
                                        allowed_categories_to_link_to = [
                                            ''
                                            ], 
                                        support_mandatory_validation = True, 
                                        custom_base_path = '', )
                                    ], 
                                built_in_attributes = [
                                    biotmed_settings_sdk.models.entity_type_built_in_attribute.EntityTypeBuiltInAttribute(
                                        name = '', 
                                        base_path = '', 
                                        type = 'LABEL', 
                                        display_name = '', 
                                        phi = True, 
                                        validation = biotmed_settings_sdk.models.validation_definition_object.ValidationDefinitionObject(
                                            mandatory = True, 
                                            default_value = null, 
                                            min = -9223372036854775808, 
                                            max = -9223372036854775808, 
                                            regex = '', ), 
                                        validation_metadata = biotmed_settings_sdk.models.validation_definition_metadata_object.ValidationDefinitionMetadataObject(
                                            mandatory_read_only = True, 
                                            system_mandatory = True, 
                                            phi_read_only = True, ), 
                                        selectable_values = [
                                            biotmed_settings_sdk.models.base_selectable_value.BaseSelectableValue(
                                                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua', 
                                                display_name = '', )
                                            ], 
                                        read_only = True, 
                                        reference_configuration = biotmed_settings_sdk.models.reference_configuration.ReferenceConfiguration(
                                            uniquely = True, 
                                            referenced_side_attribute_name = '', 
                                            referenced_side_attribute_display_name = '', 
                                            valid_templates_to_reference = [
                                                ''
                                                ], 
                                            entity_type = '', ), 
                                        numeric_meta_data = biotmed_settings_sdk.models.numeric_meta_data.NumericMetaData(
                                            units = '', 
                                            upper_range = -2147483648, 
                                            lower_range = -2147483648, 
                                            sub_type = 'INTEGER', ), 
                                        analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                                            name = '', ), 
                                        type_enum = 'LABEL', )
                                    ], 
                                template_attributes = [
                                    biotmed_settings_sdk.models.entity_type_template_attribute.EntityTypeTemplateAttribute(
                                        name = '', 
                                        base_path = '', 
                                        type = 'LABEL', 
                                        display_name = '', 
                                        phi = True, 
                                        validation = biotmed_settings_sdk.models.validation_definition_object.ValidationDefinitionObject(
                                            mandatory = True, 
                                            default_value = null, 
                                            min = -9223372036854775808, 
                                            max = -9223372036854775808, 
                                            regex = '', ), 
                                        value = null, 
                                        organization_selection = biotmed_settings_sdk.models.organization_selection.OrganizationSelection(
                                            allowed = True, 
                                            configuration = biotmed_settings_sdk.models.organization_selection_configuration.OrganizationSelectionConfiguration(
                                                selected = [
                                                    biotmed_settings_sdk.models.selected_organization.SelectedOrganization(
                                                        id = '', )
                                                    ], 
                                                all = True, ), ), 
                                        category = biotmed_settings_sdk.models.category.Category(
                                            name = '', 
                                            display_name = '', ), 
                                        type_enum = 'LABEL', )
                                    ], 
                                parent_template_type = '', 
                                caption_attributes = [
                                    biotmed_settings_sdk.models.attribute_identifier.AttributeIdentifier(
                                        name = '', 
                                        base_path = '', )
                                    ], 
                                reserved_template_names = [
                                    ''
                                    ], 
                                adding_custom_attribute_reference_type_supported = True, 
                                adding_templates_supported = True, )
                            ], 
                        attribute_categories = [
                            biotmed_settings_sdk.models.get_category_response.GetCategoryResponse(
                                name = '', 
                                display_name = '', 
                                support_mandatory_validation = True, 
                                custom_base_path = '', )
                            ], 
                        built_in_attributes = [
                            biotmed_settings_sdk.models.entity_type_built_in_attribute.EntityTypeBuiltInAttribute(
                                name = '', 
                                base_path = '', 
                                type = 'LABEL', 
                                display_name = '', 
                                phi = True, 
                                read_only = True, 
                                type_enum = 'LABEL', )
                            ], 
                        template_attributes = [
                            biotmed_settings_sdk.models.entity_type_template_attribute.EntityTypeTemplateAttribute(
                                name = '', 
                                base_path = '', 
                                type = 'LABEL', 
                                display_name = '', 
                                phi = True, 
                                validation = , 
                                value = null, 
                                category = , 
                                type_enum = 'LABEL', )
                            ], 
                        parent_template_type = '', 
                        caption_attributes = [
                            biotmed_settings_sdk.models.attribute_identifier.AttributeIdentifier(
                                name = '', 
                                base_path = '', )
                            ], 
                        reserved_template_names = [
                            ''
                            ], 
                        adding_custom_attribute_reference_type_supported = True, 
                        adding_templates_supported = True, )
                    ]
            )
        else:
            return GetEntityTypesResponse(
        )
        """

    def testGetEntityTypesResponse(self):
        """Test GetEntityTypesResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
