# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.subscription_dto import SubscriptionDto

class TestSubscriptionDto(unittest.TestCase):
    """SubscriptionDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SubscriptionDto:
        """Test SubscriptionDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SubscriptionDto`
        """
        model = SubscriptionDto()
        if include_optional:
            return SubscriptionDto(
                interception_order = 56,
                interceptions = [
                    biotmed_settings_sdk.models.interception_subscription_dto.InterceptionSubscriptionDto(
                        type = 'PRE_REQUEST', 
                        api_id = '', 
                        entity_type_name = 'device', 
                        order = 56, )
                    ],
                notifications = [
                    biotmed_settings_sdk.models.notification_subscription_dto.NotificationSubscriptionDto(
                        entity_type_name = 'device', 
                        action_name = '_create', )
                    ]
            )
        else:
            return SubscriptionDto(
        )
        """

    def testSubscriptionDto(self):
        """Test SubscriptionDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
