# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.partial_update_plugin_request import PartialUpdatePluginRequest

class TestPartialUpdatePluginRequest(unittest.TestCase):
    """PartialUpdatePluginRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PartialUpdatePluginRequest:
        """Test PartialUpdatePluginRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PartialUpdatePluginRequest`
        """
        model = PartialUpdatePluginRequest()
        if include_optional:
            return PartialUpdatePluginRequest(
                display_name = 'My Plugin 3',
                version = 1,
                runtime = 'python3.13',
                timeout = 60,
                handler = 'index.handler',
                memory_size = 128,
                environment_variables = {
                    'key' : None
                    },
                subscriptions = biotmed_settings_sdk.models.partial_update_subscription_dto.PartialUpdateSubscriptionDto(
                    interception_order = 1, 
                    interceptions = biotmed_settings_sdk.models.json_nullable_list_interception_subscription_dto.JsonNullableListInterceptionSubscriptionDto(
                        present = True, ), 
                    notifications = biotmed_settings_sdk.models.json_nullable_list_interception_subscription_dto.JsonNullableListInterceptionSubscriptionDto(
                        present = True, ), ),
                enabled_state = 'DISABLED',
                cron_schedule = '45',
                image_tag = '',
                analytics_db_access = True,
                cors = biotmed_settings_sdk.models.partial_plugin_cors_config.PartialPluginCorsConfig(
                    allow_origins = [*], 
                    allow_methods = [GET, POST], 
                    allow_headers = [authorization, content-type], 
                    expose_headers = [], ),
                ephemeral_storage = 512
            )
        else:
            return PartialUpdatePluginRequest(
                display_name = 'My Plugin 3',
                version = 1,
                runtime = 'python3.13',
                timeout = 60,
                handler = 'index.handler',
                memory_size = 128,
                environment_variables = {
                    'key' : None
                    },
                subscriptions = biotmed_settings_sdk.models.partial_update_subscription_dto.PartialUpdateSubscriptionDto(
                    interception_order = 1, 
                    interceptions = biotmed_settings_sdk.models.json_nullable_list_interception_subscription_dto.JsonNullableListInterceptionSubscriptionDto(
                        present = True, ), 
                    notifications = biotmed_settings_sdk.models.json_nullable_list_interception_subscription_dto.JsonNullableListInterceptionSubscriptionDto(
                        present = True, ), ),
                enabled_state = 'DISABLED',
                image_tag = '',
                analytics_db_access = True,
                ephemeral_storage = 512,
        )
        """

    def testPartialUpdatePluginRequest(self):
        """Test PartialUpdatePluginRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
