# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.search_response_template_minimized_response import SearchResponseTemplateMinimizedResponse

class TestSearchResponseTemplateMinimizedResponse(unittest.TestCase):
    """SearchResponseTemplateMinimizedResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchResponseTemplateMinimizedResponse:
        """Test SearchResponseTemplateMinimizedResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchResponseTemplateMinimizedResponse`
        """
        model = SearchResponseTemplateMinimizedResponse()
        if include_optional:
            return SearchResponseTemplateMinimizedResponse(
                data = [
                    biotmed_settings_sdk.models.template_minimized_response.TemplateMinimizedResponse(
                        display_name = '0', 
                        name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua0', 
                        description = '0', 
                        owner_organization_id = '', 
                        analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                            name = '', ), 
                        id = '', 
                        entity_type_name = '', 
                        removable = True, 
                        creation_time = '2007-12-20T10:15:30Z', 
                        last_modified_time = '2007-12-20T10:15:30Z', 
                        parent_template = biotmed_settings_sdk.models.parent_template_response.ParentTemplateResponse(
                            id = '', 
                            display_name = '', 
                            name = '', ), 
                        parent_template_id = '', )
                    ],
                metadata = biotmed_settings_sdk.models.metadata.Metadata(
                    sort = [
                        biotmed_settings_sdk.models.order.Order(
                            prop = '', 
                            order = 'ASC', )
                        ], 
                    filter = {
                        'key' : biotmed_settings_sdk.models.filter_v2.FilterV2(
                            in = [
                                ''
                                ], 
                            eq = null, 
                            lt = 20, 
                            lte = 25, 
                            gt = 25, 
                            gte = 25, 
                            like = 'John', 
                            from = '2007-12-20', 
                            to = '2007-12-20', 
                            is_null = True, 
                            is_not_null = True, 
                            not = null, 
                            not_in = [
                                ''
                                ], )
                        }, 
                    page = biotmed_settings_sdk.models.page_metadata.PageMetadata(
                        total_results = 145, 
                        limit = 100, ), 
                    free_text_search = 'cat dog', )
            )
        else:
            return SearchResponseTemplateMinimizedResponse(
                data = [
                    biotmed_settings_sdk.models.template_minimized_response.TemplateMinimizedResponse(
                        display_name = '0', 
                        name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua0', 
                        description = '0', 
                        owner_organization_id = '', 
                        analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                            name = '', ), 
                        id = '', 
                        entity_type_name = '', 
                        removable = True, 
                        creation_time = '2007-12-20T10:15:30Z', 
                        last_modified_time = '2007-12-20T10:15:30Z', 
                        parent_template = biotmed_settings_sdk.models.parent_template_response.ParentTemplateResponse(
                            id = '', 
                            display_name = '', 
                            name = '', ), 
                        parent_template_id = '', )
                    ],
                metadata = biotmed_settings_sdk.models.metadata.Metadata(
                    sort = [
                        biotmed_settings_sdk.models.order.Order(
                            prop = '', 
                            order = 'ASC', )
                        ], 
                    filter = {
                        'key' : biotmed_settings_sdk.models.filter_v2.FilterV2(
                            in = [
                                ''
                                ], 
                            eq = null, 
                            lt = 20, 
                            lte = 25, 
                            gt = 25, 
                            gte = 25, 
                            like = 'John', 
                            from = '2007-12-20', 
                            to = '2007-12-20', 
                            is_null = True, 
                            is_not_null = True, 
                            not = null, 
                            not_in = [
                                ''
                                ], )
                        }, 
                    page = biotmed_settings_sdk.models.page_metadata.PageMetadata(
                        total_results = 145, 
                        limit = 100, ), 
                    free_text_search = 'cat dog', ),
        )
        """

    def testSearchResponseTemplateMinimizedResponse(self):
        """Test SearchResponseTemplateMinimizedResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
