# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.metadata import Metadata

class TestMetadata(unittest.TestCase):
    """Metadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Metadata:
        """Test Metadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Metadata`
        """
        model = Metadata()
        if include_optional:
            return Metadata(
                sort = [
                    biotmed_settings_sdk.models.order.Order(
                        prop = '', 
                        order = 'ASC', )
                    ],
                filter = {
                    'key' : biotmed_settings_sdk.models.filter_v2.FilterV2(
                        in = [
                            ''
                            ], 
                        eq = null, 
                        lt = 20, 
                        lte = 25, 
                        gt = 25, 
                        gte = 25, 
                        like = 'John', 
                        from = '2007-12-20', 
                        to = '2007-12-20', 
                        is_null = True, 
                        is_not_null = True, 
                        not = null, 
                        not_in = [
                            ''
                            ], 
                        filter = null, )
                    },
                page = biotmed_settings_sdk.models.page_metadata.PageMetadata(
                    total_results = 145, 
                    page = 3, 
                    limit = 100, ),
                free_text_search = 'cat dog'
            )
        else:
            return Metadata(
        )
        """

    def testMetadata(self):
        """Test Metadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
