# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.basic_attribute_data import BasicAttributeData

class TestBasicAttributeData(unittest.TestCase):
    """BasicAttributeData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BasicAttributeData:
        """Test BasicAttributeData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BasicAttributeData`
        """
        model = BasicAttributeData()
        if include_optional:
            return BasicAttributeData(
                id = '',
                name = '',
                display_name = '',
                base_path = '',
                reference_configuration = biotmed_settings_sdk.models.reference_configuration.ReferenceConfiguration(
                    uniquely = True, 
                    referenced_side_attribute_name = '', 
                    referenced_side_attribute_display_name = '', 
                    valid_templates_to_reference = [
                        ''
                        ], 
                    entity_type = '', ),
                template = biotmed_settings_sdk.models.basic_template_data.BasicTemplateData(
                    id = '', 
                    name = '', 
                    display_name = '', 
                    entity_type_name = '', )
            )
        else:
            return BasicAttributeData(
        )
        """

    def testBasicAttributeData(self):
        """Test BasicAttributeData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
