# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.entity_type_built_in_action import EntityTypeBuiltInAction

class TestEntityTypeBuiltInAction(unittest.TestCase):
    """EntityTypeBuiltInAction unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EntityTypeBuiltInAction:
        """Test EntityTypeBuiltInAction
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EntityTypeBuiltInAction`
        """
        model = EntityTypeBuiltInAction()
        if include_optional:
            return EntityTypeBuiltInAction(
                name = '',
                base_path = '',
                display_name = '',
                enable_notification = True,
                enable_log = True,
                timeout_in_seconds = 56,
                source = '',
                category = biotmed_settings_sdk.models.category.Category(
                    name = '', 
                    display_name = '', )
            )
        else:
            return EntityTypeBuiltInAction(
                name = '',
        )
        """

    def testEntityTypeBuiltInAction(self):
        """Test EntityTypeBuiltInAction"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
