# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.template_overview_response import TemplateOverviewResponse

class TestTemplateOverviewResponse(unittest.TestCase):
    """TemplateOverviewResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TemplateOverviewResponse:
        """Test TemplateOverviewResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TemplateOverviewResponse`
        """
        model = TemplateOverviewResponse()
        if include_optional:
            return TemplateOverviewResponse(
                statistics = biotmed_settings_sdk.models.template_statistics.TemplateStatistics(
                    entities_count = 56, ),
                referenced_by_attributes = [
                    biotmed_settings_sdk.models.basic_attribute_data.BasicAttributeData(
                        id = '', 
                        name = '', 
                        display_name = '', 
                        base_path = '', 
                        reference_configuration = biotmed_settings_sdk.models.reference_configuration.ReferenceConfiguration(
                            uniquely = True, 
                            referenced_side_attribute_name = '', 
                            referenced_side_attribute_display_name = '', 
                            valid_templates_to_reference = [
                                ''
                                ], 
                            entity_type = '', ), 
                        template = biotmed_settings_sdk.models.basic_template_data.BasicTemplateData(
                            id = '', 
                            name = '', 
                            display_name = '', 
                            entity_type_name = '', ), )
                    ]
            )
        else:
            return TemplateOverviewResponse(
        )
        """

    def testTemplateOverviewResponse(self):
        """Test TemplateOverviewResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
