# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.api.backup_api_api import BackupAPIApi


class TestBackupAPIApi(unittest.TestCase):
    """BackupAPIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BackupAPIApi()

    def tearDown(self) -> None:
        pass

    def test_backup(self) -> None:
        """Test case for backup

        Backup
        """
        pass

    def test_search_backup_executions(self) -> None:
        """Test case for search_backup_executions

        Search Backup entities by filter
        """
        pass

    def test_search_restore_executions(self) -> None:
        """Test case for search_restore_executions

        Search Restore entities by filter
        """
        pass


if __name__ == '__main__':
    unittest.main()
